FL.objects.Dialog.Dialog
========================

.. currentmodule:: FL.objects.Dialog

.. autoclass:: Dialog
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Dialog.AddControl
      ~Dialog.Center
      ~Dialog.Enable
      ~Dialog.End
      ~Dialog.GetRect
      ~Dialog.GetValue
      ~Dialog.PutValue
      ~Dialog.Repaint
      ~Dialog.Run
      ~Dialog.SetLabel
      ~Dialog.Show
      ~Dialog.__init__
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Dialog.size
      ~Dialog.title
   
   